package com.ruoyi.project.reliability.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.reliability.mapper.TAssetlistMapper;
import com.ruoyi.project.reliability.domain.TAssetlist;
import com.ruoyi.project.reliability.service.ITAssetlistService;

import javax.annotation.Resource;

/**
 * 资产清单Service业务层处理
 *
 * @author ruoyi
 * @date 2020-11-27
 */
@Service
public class TAssetlistServiceImpl implements ITAssetlistService
{
    @Resource
    private TAssetlistMapper tAssetlistMapper;

    /**
     * 查询资产清单
     *
     * @param id 资产清单ID
     * @return 资产清单
     */
    @Override
    public TAssetlist selectTAssetlistById(Long id)
    {
        return tAssetlistMapper.selectTAssetlistById(id);
    }

    /**
     * 查询资产清单列表
     *
     * @param tAssetlist 资产清单
     * @return 资产清单
     */
    @Override
    public List<TAssetlist> selectTAssetlistList(TAssetlist tAssetlist)
    {
        return tAssetlistMapper.selectTAssetlistList(tAssetlist);
    }

    /**
     * 新增资产清单
     *
     * @param tAssetlist 资产清单
     * @return 结果
     */
    @Override
    public int insertTAssetlist(TAssetlist tAssetlist)
    {
        return tAssetlistMapper.insertTAssetlist(tAssetlist);
    }

    /**
     * 修改资产清单
     *
     * @param tAssetlist 资产清单
     * @return 结果
     */
    @Override
    public int updateTAssetlist(TAssetlist tAssetlist)
    {
        return tAssetlistMapper.updateTAssetlist(tAssetlist);
    }

    /**
     * 批量删除资产清单
     *
     * @param ids 需要删除的资产清单ID
     * @return 结果
     */
    @Override
    public int deleteTAssetlistByIds(Long[] ids)
    {
        return tAssetlistMapper.deleteTAssetlistByIds(ids);
    }

    /**
     * 删除资产清单信息
     *
     * @param id 资产清单ID
     * @return 结果
     */
    @Override
    public int deleteTAssetlistById(Long id)
    {
        return tAssetlistMapper.deleteTAssetlistById(id);
    }
}
